{% spaceless %}

<li>
    {% if node.has_content %}
    <a href="{{ plugins.docimport.path }}{{ node.url }}">{{ node.title }}</a>
    {% else %}
    <span>{{ node.title }}</span>
    {% endif %}

    {% if node.children.count %}
    <ul>
        {% for child in node.children %}
            {% with node=child %}
                {% include "naremitcms-docimport/menu.html" %}
            {% endwith %}
        {% endfor %}
    </ul>
    {% endif %}
</li>

{% endspaceless %}
