<!DOCTYPE html>

<html>
    <head>
        <title>NaremitCMS DocImport Example</title>
        <style>
            * { font-family: sans-serif; margin: 0; padding: 0; }
            body { background: #eee; }
            div { background: #fff; margin: 20px auto; max-width: 900px; overflow: hidden; padding: 20px; }
            div > div { margin: 20px 0 0; max-width: auto; padding: 0; }
            .menu { float: left; width: 280px; }
            .content { float: right; width: 600px; }
            ul { padding-left: 25px !important; }
        </style>
    </head>
    <body>
        <div>
            <h1>Example Documentation</h1>
            <div class="menu">
                <ul>
                    {% for node in plugins.docimport.tree %}
                        {% include "naremitcms-docimport/menu.html" %}
                    {% endfor %}
                </ul>
            </div>

            <div class="content">{{ plugins.docimport.html|safe }}</div>
        </div>
    </body>
</html>
